@@ -25,6 +25,8 @@ else:
 
 __all__ = (
     "ConditionExpressionTypeDef",
+    "CsvOptionsTypeDef",
+    "CsvOutputOptionsTypeDef",
     "DataCatalogInputDefinitionTypeDef",
     "DatasetTypeDef",
     "ExcelOptionsTypeDef",
@@ -33,6 +35,7 @@ __all__ = (
     "JobRunTypeDef",
     "JobTypeDef",
     "JsonOptionsTypeDef",
+    "OutputFormatOptionsTypeDef",
     "OutputTypeDef",
     "ProjectTypeDef",
     "RecipeActionTypeDef",
@@ -98,6 +101,10 @@ class ConditionExpressionTypeDef(
     pass
 
 
+CsvOptionsTypeDef = TypedDict("CsvOptionsTypeDef", {"Delimiter": str}, total=False)
+
+CsvOutputOptionsTypeDef = TypedDict("CsvOutputOptionsTypeDef", {"Delimiter": str}, total=False)
+
 _RequiredDataCatalogInputDefinitionTypeDef = TypedDict(
     "_RequiredDataCatalogInputDefinitionTypeDef", {"DatabaseName": str, "TableName": str}
 )
@@ -144,7 +151,7 @@ ExcelOptionsTypeDef = TypedDict(
 
 FormatOptionsTypeDef = TypedDict(
     "FormatOptionsTypeDef",
-    {"Json": "JsonOptionsTypeDef", "Excel": "ExcelOptionsTypeDef"},
+    {"Json": "JsonOptionsTypeDef", "Excel": "ExcelOptionsTypeDef", "Csv": "CsvOptionsTypeDef"},
     total=False,
 )
 
@@ -214,6 +221,10 @@ class JobTypeDef(_RequiredJobTypeDef, _OptionalJobTypeDef):
 
 JsonOptionsTypeDef = TypedDict("JsonOptionsTypeDef", {"MultiLine": bool}, total=False)
 
+OutputFormatOptionsTypeDef = TypedDict(
+    "OutputFormatOptionsTypeDef", {"Csv": "CsvOutputOptionsTypeDef"}, total=False
+)
+
 _RequiredOutputTypeDef = TypedDict("_RequiredOutputTypeDef", {"Location": "S3LocationTypeDef"})
 _OptionalOutputTypeDef = TypedDict(
     "_OptionalOutputTypeDef",
@@ -224,6 +235,7 @@ _OptionalOutputTypeDef = TypedDict(
         "Format": Literal["CSV", "JSON", "PARQUET", "GLUEPARQUET", "AVRO", "ORC", "XML"],
         "PartitionColumns": List[str],
         "Overwrite": bool,
+        "FormatOptions": "OutputFormatOptionsTypeDef",
         "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
